@@ -30,6 +30,8 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
+#include <iphbd/libiphb.h>
+
 #ifdef __cplusplus 
 extern "C" { 
 #endif
@@ -105,17 +107,33 @@ extern const gint all_autoupdate_time[];
 //#define RSS_AUTO_UPDATE_DEFAULT_INT 1
 #define RSS_AUTO_UPDATE_DEFAULT_INT 3
 
+/* Rama - Structure for iphb */
+typedef struct {
+	GSourceFunc iphb_callback;
+	iphb_t iphb_handle;
+	gint source_id;
+	gpointer user_data;
+} Iphb_cb_data;
+
 gint find_cache_size(gint cacheSizeConf);
-gboolean execute_rss_settings(osso_context_t *osso, gpointer window, gboolean modal, gboolean executed_from_applet);
+gboolean execute_rss_settings(osso_context_t *osso, gpointer window, gboolean modal, gboolean executed_from_applet, Iphb_cb_data *iphb_data);
 void close_rss_settings();
-void setup_alarm_event(gboolean replace);
-gboolean setup_alarm_event_now(gboolean replace);
+void setup_alarm_event(gboolean replace, Iphb_cb_data *data);
+gboolean setup_alarm_event_now(gboolean replace, Iphb_cb_data *data);
 void conf_reset_default_values(GConfClient* conf);
 gboolean is_first_time_run(GConfClient* conf);
 void config_check_first_time(GConfClient* conf);
-gint _setup_alarm_timeout(gpointer data);
+gboolean _setup_alarm_timeout(gpointer data);
 void delete_allalarm_events();
 
+/* Rama - adding ipHB support */
+gboolean remove_iphb_callback(guint source_id);
+//guint setup_iphb_callback(GSourceFunc funcPtr);
+guint setup_iphb_callback(Iphb_cb_data *data);
+int get_iphb_fd(iphb_t iphb_handle);
+iphb_t create_iphb_handle(void);
+iphb_t close_iphb_handle(Iphb_cb_data data);
+
 #ifdef __cplusplus 
 }
 #endif
